@@ -20,15 +20,8 @@
 #OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 #SOFTWARE.
 
-from pida.utils.testing.mock import Mock
-from unittest import TestCase
-
-class Test(TestCase):
-
-    def test_plugin(self):
-        pass
 
 
 
 
-# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
\ No newline at end of file
+# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
