@@ -2,7 +2,15 @@
 The Python Integrated Development Application IDE Framework
 """
 
-version = '0.6.1'
+try:
+    version = __import__('pkg_resources') \
+            .get_distribution('pida').version
+except Exception:  # DistributionNotFound
+    try:
+        import hgdistver
+        version = hgdistver.get_version()
+    except ImportError:
+        version = 'unknown'
 
 copyright = 'Copyright (c) 2005-2009 The PIDA Project'
 
