@@ -59,9 +59,9 @@ from pida.core.actions import TYPE_NORMAL, TYPE_TOGGLE
 from pida.core.events import EventsConfig
 from pida.core.document import DocumentException
 from pida.core.options import OptionsConfig, choices
-from pida.utils.completer import (PidaCompleter, PidaCompleterWindow, 
+from pida.ui.completer import (PidaCompleter, PidaCompleterWindow, 
     SuggestionsList)
-from pida.utils.gthreads import GeneratorTask, gcall, AsyncTask
+from pygtkhelpers.gthreads import GeneratorTask, gcall, AsyncTask
 from pida.core.languages import Suggestion
 from pida.ui.languages import PidaDocWindow
 
