@@ -4,12 +4,10 @@
     :license: GPL 2 or later (see README/COPYING/LICENSE)
 """
 import os
-from tempfile import mkstemp
 
 import gtk
 import time
 
-from pygtkhelpers.ui.objectlist import Column
 
 # PIDA Imports
 from pida.core.service import Service
@@ -19,126 +17,21 @@ from pida.core.options import OptionsConfig, choices
 from pida.core.events import EventsConfig
 from pida.core.actions import ActionsConfig
 from pida.core.pdbus import DbusConfig, EXPORT
-from pida.core.actions import TYPE_NORMAL, TYPE_MENUTOOL, TYPE_RADIO, TYPE_TOGGLE
 
-from pida.ui.views import PidaGladeView, WindowConfig
-from pida.ui.objectlist import AttrSortCombo
+from pida.ui.views import WindowConfig
 from pida.core.document import Document, DocumentException
 
-from pida.utils.gthreads import gcall
+from pygtkhelpers.gthreads import gcall
 
 # locale
 from pida.core.locale import Locale
 locale = Locale('buffer')
 _ = locale.gettext
 
+from .view import BufferListView, attributes
+
 LEXPORT = EXPORT(suffix='buffer')
 
-attributes = {
-    'onerow': 'markup',
-    'tworow': 'markup_tworow',
-}
-
-class BufferListView(PidaGladeView):
-
-    key = 'buffer.list'
-    gladefile = 'buffer_list'
-    locale = locale
-    icon_name = 'package_office'
-
-    label_text = _('Buffers')
-
-    def create_ui(self ):
-        self.buffers_ol.set_columns([
-            Column('markup', use_markup=True),
-            Column('markup_tworow', use_markup=True, visible=False),
-            Column("basename", visible=False, searchable=True),
-        ])
-
-        self.buffers_ol.set_headers_visible(False)
-        self._sort_combo = AttrSortCombo(self.buffers_ol,
-            [
-                ('creation_time', _('Time Opened')),
-                ('filename', _('File path')),
-                ('basename', _('File name')),
-                ('mimetype', _('Mime Type')),
-                ('doctype', _('Document Type')),
-                ('length', _('File Length')),
-                ('modified_time', _('Last Modified')),
-                ('usage', _('View Counter')),
-                ('last_opend', _('Last Opened')),
-                #('Project', _('Project_name'))
-            ],
-            'creation_time' 
-        )
-        self._sort_combo.show()
-        self.toplevel.pack_start(self._sort_combo, expand=False)
-
-    def add_document(self, document):
-        self.buffers_ol.append(document)
-
-    def remove_document(self, document):
-        self.buffers_ol.remove(document)
-
-    def set_document(self, document):
-        if self.buffers_ol.selected_item is not document:
-            self.buffers_ol.selected_item = document
-
-    def view_document(self, document):
-        self.svc.view_document(document)
-        self.svc.boss.editor.cmd('grab_focus')
-
-    def on_buffers_ol__item_double_clicked(self, ol, item, ev=None):
-        self.view_document(item)
-
-    def on_buffers_ol__item_activated(self, ol, item):
-        self.view_document(item)
-
-    def on_buffers_ol__item_right_clicked(self, ol, item, event=None):
-        menu = self.svc.boss.cmd('contexts', 'get_menu', context='file-menu',
-                                 document=item, file_name=item.filename)
-
-        # Add some stuff to the menu
-        close = self.svc.get_action('close_selected').create_menu_item()
-        menu.insert(close, 2)
-
-        menu.show_all()
-        menu.popup(None, None, None, event.button, event.time)
-
-        # Must leave the menu in the same state we found it!
-        def on_deactivate(menu):
-            #menu.remove(sep)
-            menu.remove(close)
-
-        menu.connect('deactivate', on_deactivate)
-
-    def get_current_buffer_index(self):
-        return self.buffers_ol.selected_item
-
-    def select_buffer_by_index(self, index):
-        self.buffers_ol.select(self.buffers_ol[index])
-        self.view_document(self.buffers_ol[index])
-
-    # note current is the current buffer, not the current selected buffer
-    def next_buffer(self):
-        next = self.buffers_ol.item_after(self.svc.get_current())
-        if next is None:
-            next = self.buffers_ol[0]
-        self.svc.open_file(document=next)
-
-    def prev_buffer(self):
-        prev = self.buffers_ol.item_before(self.svc.get_current())
-        if prev is None:
-            prev = self.buffers_ol[-1]
-        self.svc.open_file(document=prev)
-
-    def sort(self):
-        self.buffers_ol.get_model().sort_column_changed()
-
-    def set_display_attr(self, newattr):
-        for attr in attributes.values():
-            for col in self.buffers_ol._viewcols_for_attr(attr):
-                col.props.visible = attr==newattr
 
 
 class BufferActionsConfig(ActionsConfig):
@@ -146,7 +39,7 @@ class BufferActionsConfig(ActionsConfig):
     def create_actions(self):
         self.create_action(
             'open_file',
-            TYPE_NORMAL,
+            gtk.Action,
             _('_Open File'),
             _('Open a file with a graphical file browser'),
             gtk.STOCK_OPEN,
@@ -156,7 +49,7 @@ class BufferActionsConfig(ActionsConfig):
 
         self.create_action(
             'open-for-file',
-            TYPE_NORMAL,
+            gtk.Action,
             _('Open File'),
             _('Open this file'),
             gtk.STOCK_OPEN,
@@ -165,7 +58,7 @@ class BufferActionsConfig(ActionsConfig):
 
         self.create_action(
             'new_file',
-            TYPE_NORMAL,
+            gtk.Action,
             _('_New File'),
             _('Create a new file'),
             gtk.STOCK_NEW,
@@ -175,7 +68,7 @@ class BufferActionsConfig(ActionsConfig):
 
         self.create_action(
             'create_file',
-            TYPE_NORMAL,
+            gtk.Action,
             _('Cr_eate File'),
             _('Create a new file'),
             gtk.STOCK_ADD,
@@ -185,7 +78,7 @@ class BufferActionsConfig(ActionsConfig):
 
         self.create_action(
             'close',
-            TYPE_NORMAL,
+            gtk.Action,
             _('_Close Document'),
             _('Close the current document'),
             gtk.STOCK_CLOSE,
@@ -195,7 +88,7 @@ class BufferActionsConfig(ActionsConfig):
 
         self.create_action(
             'close_all',
-            TYPE_NORMAL,
+            gtk.Action,
             _('Close all Documents'),
             _('Close all documents'),
             '',
@@ -204,7 +97,7 @@ class BufferActionsConfig(ActionsConfig):
         )
         self.create_action(
             'switch_next_buffer',
-            TYPE_NORMAL,
+            gtk.Action,
             _('_Next Buffer'),
             _('Switch to the next buffer'),
             gtk.STOCK_GO_DOWN,
@@ -214,7 +107,7 @@ class BufferActionsConfig(ActionsConfig):
 
         self.create_action(
             'switch_prev_buffer',
-            TYPE_NORMAL,
+            gtk.Action,
             _('_Previous Buffer'),
             _('Switch to the previous buffer'),
             gtk.STOCK_GO_UP,
@@ -223,7 +116,7 @@ class BufferActionsConfig(ActionsConfig):
         )
         self.create_action(
             'show_buffer_list',
-            TYPE_NORMAL,
+            gtk.Action,
             _('Show _buffer browser'),
             _('Displays the buffer window'),
             '',
@@ -234,7 +127,7 @@ class BufferActionsConfig(ActionsConfig):
 
         self.create_action(
             'close_selected',
-            TYPE_NORMAL,
+            gtk.Action,
             _('_Close Document'),
             _('Close the selected document'),
             gtk.STOCK_CLOSE,
@@ -423,7 +316,7 @@ class BufferDbusConfig(DbusConfig):
     @LEXPORT(out_signature='a(isiia{ss})')
     def get_documents(self):
         return [
-                 (x.unique_id, x.filename, 
+                 (id(x), x.filename, 
                        x.doctype and x.doctype.internal or '', 
                        x.creation_time,
                        # extended values
@@ -466,7 +359,7 @@ class Buffer(Service):
 
     def _refresh_buffer_action_sensitivities(self):
         for action_name in ['switch_next_buffer', 'switch_prev_buffer']:
-            self.get_action(action_name).set_sensitive(len(self._documents) > 0)
+            self.get_action(action_name).set_sensitive(bool(self._documents))
 
     def new_file(self, do_open=True, with_editor_id=None):
         return self.open_file(editor_buffer_id=with_editor_id)
@@ -572,13 +465,13 @@ class Buffer(Service):
 
     def _add_document(self, document):
         self._last_added_document = document
-        self._documents[document.unique_id] = document
+        self._documents[id(document)] = document
         self._view.add_document(document)
         self._refresh_buffer_action_sensitivities()
 
     def _remove_document(self, document):
         "_remove_doc", document
-        del self._documents[document.unique_id]
+        del self._documents[id(document)]
         self._view.remove_document(document)
         self._refresh_buffer_action_sensitivities()
 
