@@ -22,7 +22,7 @@ from pida.core.actions import ActionsConfig
 from pida.core.options import OptionsConfig
 from pida.core.actions import TYPE_NORMAL, TYPE_MENUTOOL, TYPE_RADIO, TYPE_TOGGLE
 
-from pida.utils.gthreads import AsyncTask
+from pygtkhelpers.gthreads import AsyncTask
 from pida.utils import ostools
 
 from pida.ui.views import PidaView
@@ -611,13 +611,12 @@ class PythonView(PidaView):
 
     def execute(self, file_=None, cwd=os.getcwd()):
         commandargs = [
-            self.svc.opt('python_path'),
-            '-m', 'bpython.gtk_',
-            '--socket-id=%s' %self._socket.get_id(),
+            'bpython-gtk',
+            '--socket-id=%s' % self._socket.get_id(),
             ]
         if file_:
             commandargs.extend(['-i', file_])
-        self.popen = p = subprocess.Popen(commandargs, cwd=cwd, close_fds=True)
+        self.popen = p = subprocess.Popen(commandargs, cwd=cwd)
         self._pid = p.pid
 
     def can_be_closed(self):
