@@ -16,7 +16,7 @@ import gtk
 from pida.core.doctype import DocType
 from pida.core.languages import LanguageInfo
 
-from pida.utils.gthreads import gcall
+from pygtkhelpers.gthreads import gcall
 #from pida.utils.languages import LANG_OUTLINER_TYPES
 from pida.utils.addtypes import PriorityList
 
@@ -55,8 +55,10 @@ LEXPORT = EXPORT(suffix='language')
 # we have to put our type database here, as plugins may need it long before
 # registering
 from .__init__ import DOCTYPES
-from .gui import (ValidatorView, BrowserView, LanguageEntry,
-                 LanguagePriorityView, DefinitionView)
+from .views import (
+    ValidatorView, BrowserView, DefinitionView,
+    LanguageEntry, LanguagePriorityView,
+)
 
 def get_value(tab, key):
     return tab.get(key, None)
