@@ -15,7 +15,6 @@
 
     :license: GPL2 or later
 """
-from __future__ import with_statement
 import StringIO
 
 
@@ -28,14 +27,14 @@ import shutil
 import pida.plugins
 
 from pygtkhelpers.ui.objectlist import Column
-from pida.ui.views import PidaGladeView, WindowConfig
+from pida.ui.views import PidaView, WindowConfig
 from pida.core.commands import CommandsConfig
 from pida.core.service import Service
 from pida.core.events import EventsConfig
 from pida.core.features import FeaturesConfig
 from pida.core.options import OptionsConfig
 from pida.core.actions import ActionsConfig, TYPE_TOGGLE
-from pida.utils.gthreads import GeneratorTask, AsyncTask, gcall
+from pygtkhelpers.gthreads import GeneratorTask, AsyncTask, gcall
 from pida.core.servicemanager import ServiceLoader, ServiceLoadingError
 
 from pida.core.environment import plugins_dir
@@ -60,11 +59,11 @@ class PluginsEditItem(object):
         self.name = name
         self.value = value
 
-class PluginsEditView(PidaGladeView):
+class PluginsEditView(PidaView):
 
     key = 'plugins.editor'
 
-    gladefile = 'plugins_edit'
+    builder_file = 'plugins_edit'
     locale = locale
     label_text = _('Edit a plugin')
     icon_name = gtk.STOCK_EXECUTE
@@ -106,11 +105,11 @@ class PluginsEditView(PidaGladeView):
         self.svc.hide_plugins_edit()
 
 
-class PluginsView(PidaGladeView):
+class PluginsView(PidaView):
 
     key = 'plugins.view'
 
-    gladefile = 'plugins_manager'
+    builder_file = 'plugins_manager'
     locale = locale
     label_text = _('Plugins manager')
     icon_name = gtk.STOCK_EXECUTE
@@ -198,7 +197,6 @@ class PluginsView(PidaGladeView):
         directory = self.publish_directory.get_filename()
         if self.svc.is_plugin_directory(directory):
             self.item = self.svc.read_plugin_informations(directory)
-            self.item.directory = directory
             self.publish_button.set_sensitive(True)
             self.publish_edit_button.set_sensitive(True)
             self.svc._viewedit.set_item(self.item)
@@ -508,7 +506,6 @@ class Plugins(Service):
 
     def install(self, item, content):
         item.base = plugins_dir
-        item.directory = os.path.join(plugins_dir, item.plugin)
 
         # this will gracefully ignore not installed plugins
         self.delete(item, force=True)
@@ -605,20 +602,18 @@ class Plugins(Service):
         self.set_opt('start_list', list)
 
     def _get_item_markup(self, item):
-        markup = '<b>%s</b>' % cgi.escape(item.name or str(item))
-        if item.version:
-            markup += '\n<b>%s</b> : %s' % (_('Version'),
-                    cgi.escape(item.version))
-        if item.author:
-            markup += '\n<b>%s</b> : %s' % (_('Author'),
-                    cgi.escape(item.author))
-        if item.category:
-            markup += '\n<b>%s</b> : %s' % (_('Category'),
-                    cgi.escape(item.category))
-        if item.depends:
-            markup += '\n<b>%s</b> : %s' % (_('Depends'),
-                    cgi.escape(item.depends))
-        return markup
+        markup = ['<b>%s</b>' % cgi.escape(item.name or str(item))]
+        addstr = '<b>%s</b> : %s'
+        def maybe_markup(name, label):
+            attr = getattr(item, name)
+            if attr:
+                attr = cgi.escape(attr)
+                markup.append(addstr % (label, attr))
+        maybe_markup('version', _('Version'))
+        maybe_markup('author', _('Author'))
+        maybe_markup('category', _('Category'))
+        maybe_markup('depends', _('Depends'))
+        return '\n'.join(markup)
 
 
     def check_for_updates(self, check):
