@@ -1,30 +1,18 @@
 # -*- coding: utf-8 -*- 
-# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
-# $Id: base.py 352 2005-07-14 00:16:02Z gcbirzan $
-#Copyright (c) 2005 Ali Afshar aafshar@gmail.com
+"""
+    The dialog thats shown on the first run
 
-#Permission is hereby granted, free of charge, to any person obtaining a copy
-#of this software and associated documentation files (the "Software"), to deal
-#in the Software without restriction, including without limitation the rights
-#to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-#copies of the Software, and to permit persons to whom the Software is
-#furnished to do so, subject to the following conditions:
-
-#The above copyright notice and this permission notice shall be included in
-#all copies or substantial portions of the Software.
-
-#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-#IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-#FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-#AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-#LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-#OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-#SOFTWARE.
+    :copyright: 2005-2008 by The PIDA Project
+    :license: GPL 2 or later (see README/COPYING/LICENSE)
+"""
+import os
 import gtk
-from pida.pidagtk.contentview import create_pida_icon
+import pida
 
-im = gtk.Image()
-im.set_from_pixbuf(create_pida_icon())
+pida_icon = gtk.Image()
+pida_icon.set_from_file(os.path.join(
+    pida.__path__[0],
+    'resources/pixmaps/pida-icon.png'))
 
 class FirstTimeWindow(object):
 
@@ -38,7 +26,7 @@ class FirstTimeWindow(object):
         self.win.vbox.pack_start(hbox)
         logo = gtk.Image()
         logofrm = gtk.Alignment(0, 0, 0.1, 0.1)
-        logofrm.add(im)
+        logofrm.add(pida_icon)
         hbox.pack_start(logofrm, padding=8)
         box = gtk.VBox()
         hbox.pack_start(box, padding=8)
@@ -48,10 +36,12 @@ class FirstTimeWindow(object):
         l.set_markup(s)
         box.pack_start(l, expand=False, padding=8)
         self.radio = gtk.RadioButton()
+        self.editors = {}
         for editor in editors:
+            self.editors[editor.get_label()] = editor.get_name()
             ebox = gtk.HBox(spacing=6)
             box.pack_start(ebox, expand=False, padding=4)
-            radio = gtk.RadioButton(self.radio, label=editor.display_name)
+            radio = gtk.RadioButton(self.radio, label=editor.get_label())
             ebox.pack_start(radio)
             cbox = gtk.VBox(spacing=3)
             label = gtk.Label()
@@ -73,9 +63,10 @@ class FirstTimeWindow(object):
         editor_name = self.get_editor_option()
         self.win.destroy()
         # Only write the token file if we want the user chose something
-        if response == gtk.RESPONSE_ACCEPT:
+        success = (response == gtk.RESPONSE_ACCEPT)
+        if success:
             self.write_file(filename)
-        return (response, editor_name)
+        return (success, editor_name)
 
     def cb_sanity(self, button, component, radio, label):
         errs =  component.get_sanity_errors()
@@ -92,12 +83,12 @@ class FirstTimeWindow(object):
             label.set_markup('<span size="small" foreground="#00c000">'
                              '<i>Okay to use</i></span>')
             button.set_sensitive(False)
-    
+
     def get_editor_option(self, *args):
         for radio in self.radio.get_group():
             if radio.get_active():
                 editor = radio.get_label()
-                return editor
+                return self.editors[editor]
 
     def write_file(self, filename):
         f = open(filename, 'w')
@@ -105,6 +96,15 @@ class FirstTimeWindow(object):
         f.close()
 
 if __name__ == '__main__':
-    ftw = FirstTimeWindow([])
-    print ftw.run('/home/ali/.firstrun')
+    from pida.editors.vim.vim import Vim
+    from pida.editors.mooedit.mooedit import Mooedit
+    ftw = FirstTimeWindow([Vim, Mooedit])
+    print ftw.run('~/firstrun')
 
+
+
+
+
+
+
+# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
